@@ -1,7 +1,7 @@
 import docker
 from dagster_docker.utils import DOCKER_CONFIG_SCHEMA, validate_docker_config, validate_docker_image
 
-from dagster import check
+import dagster._check as check
 from dagster.core.launcher.base import (
     CheckRunHealthResult,
     LaunchRunContext,
